@@ -7,14 +7,15 @@
 #' @export
 #' @importFrom R6 R6Class
 #' @importFrom uniformly runif_in_ellipsoid runif_on_ellipsoid
+#' @importFrom Carlson elliptic_E
 Ellipse <- R6Class(
 
   "Ellipse",
 
   private = list(
     .center = c(NA_real_, NA_real_),
-    .rmajor = c(NA_real_, NA_real_),
-    .rminor = c(NA_real_, NA_real_),
+    .rmajor = NA_real_,
+    .rminor = NA_real_,
     .alpha = NA_real_,
     .degrees = NA
   ),
@@ -258,19 +259,49 @@ Ellipse <- R6Class(
 
     #' @description Path that forms the reference ellipse.
     #' @param npoints number of points of the path
+    #' @param closed Boolean, whether to return a closed path; you don't need
+    #'   a closed path if you want to plot it with
+    #'   \code{\link[graphics:polygon]{polygon}}
+    #' @param outer Boolean; if \code{TRUE}, the ellipse will be contained
+    #'   inside the path, otherwise it will contain the path
     #' @return A matrix with two columns \code{x} and \code{y} of
-    #' length \code{npoints}.
-    path = function(npoints = 100L){
-      center <- private[[".center"]]
+    #'   length \code{npoints}.
+    #' @examples
+    #' library(PlaneGeometry)
+    #' ell <- Ellipse$new(c(1, -1), rmajor = 3, rminor = 2, alpha = 30)
+    #' innerPath <- ell$path(npoints = 10)
+    #' outerPath <- ell$path(npoints = 10, outer = TRUE)
+    #' bbox <- ell$boundingbox()
+    #' plot(NULL, asp = 1, xlim = bbox$x, ylim = bbox$y, xlab = NA, ylab = NA)
+    #' draw(ell, border = "red", lty = "dashed")
+    #' polygon(innerPath, border = "blue", lwd = 2)
+    #' polygon(outerPath, border = "green", lwd = 2)
+    path = function(npoints = 100L, closed = FALSE, outer = FALSE){
       alpha <- private[[".alpha"]]
       if(private[[".degrees"]]) alpha <- alpha * pi/180
-      .ellipsePoints(
-        seq(0, 2*pi, length.out = npoints+1L)[-1L],
-        private[[".center"]],
-        private[[".rmajor"]],
-        private[[".rminor"]],
-        alpha
-      )
+      if(outer) {
+        .ellipsePointsOuter(
+          closed,
+          private[[".center"]],
+          private[[".rmajor"]],
+          private[[".rminor"]],
+          alpha,
+          as.integer(npoints)
+        )
+      } else {
+        if(closed) {
+          t_ <- seq(0, 2*pi, length.out = npoints)
+        } else {
+          t_ <- seq(0, 2*pi, length.out = npoints+1L)[-1L]
+        }
+        .ellipsePoints(
+          t_,
+          private[[".center"]],
+          private[[".rmajor"]],
+          private[[".rminor"]],
+          alpha
+        )
+      }
     },
 
     #' @description Diameter and conjugate diameter of the reference ellipse.
@@ -310,6 +341,13 @@ Ellipse <- R6Class(
       }
     },
 
+    #' @description Perimeter of the reference ellipse.
+    perimeter = function() {
+      a <- private[[".rmajor"]]
+      b <- private[[".rminor"]]
+      4 * a * Re(elliptic_E(pi/2, 1-b^2/a^2, minerror = 1e-12))
+    },
+
     #' @description Intersection point of the ellipse with the half-line
     #' starting at the ellipse center and forming angle \code{theta} with
     #' the major axis.
@@ -694,7 +732,7 @@ EllipseEquationFromFivePoints <- function(P1, P2, P3, P4, P5){
 EllipseFromEquation <- function(A, B, C, D, E, F){
   stopifnot(A*C > 0)
   if(B*B-4*A*C >= 0) stop("These parameters do not define an ellipse.")
-  if(D*D + E*E <= 4*(A+C)*F) stop("These parameters do not define an ellipse.")
+  #if(D*D + E*E <= 4*(A+C)*F) stop("These parameters do not define an ellipse.")
   Q <- rbind(c(2*A, B, D), c(B, 2*C, E), c(D, E, 2*F))
   if(det(Q) == 0) stop("These parameters do not define an ellipse.")
   M0 <- matrix(c(F, D/2, E/2, D/2, A, B/2, E/2, B/2, C), 3L, 3L)
